@@ -474,9 +474,17 @@ class ChangesProcessor(Object):
             product.codes.remove(code)
 
     def process_price_chg(self, row, session):
-        upc = row['F01']
+        """
+        Process a price change.
+        """
+        upc = row[u'F01']
         if not upc.isdigit():
-            log.warning("invalid upc: {0}".format(repr(upc)))
+            log.warning(u"invalid upc: {0}".format(repr(upc)))
+            return
+
+        if row[u'F1000'] != u'PAL':
+            log.debug(u"ignoring price change for target {0} for upc: {1}".format(
+                    repr(row[u'F1000']), repr(row[u'F01'])))
             return
 
         product = self.get_product(upc, session)
